# Table of Contents

- [access-tokens-required-for-scim](<./access-tokens-required-for-scim.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Access Tokens Required for SCIM](<./Access-Tokens-Required-for-SCIM.md>)
  - [Get a Short-Lived Access Token](<./Access-Tokens-Required-for-SCIM/Get-a-Short-Lived-Access-Token.md>)
  - [Get a Long-Lived Access Token](<./Access-Tokens-Required-for-SCIM/Get-a-Long-Lived-Access-Token.md>)
  - [Get All Long-Lived Access Tokens](<./Access-Tokens-Required-for-SCIM/Get-All-Long-Lived-Access-Tokens.md>)
  - [Deactivate a Long-Lived Access Token](<./Access-Tokens-Required-for-SCIM/Deactivate-a-Long-Lived-Access-Token.md>)
  - [Was this page helpful?](<./Access-Tokens-Required-for-SCIM/Was-this-page-helpful.md>)
